@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 describe 'App::Views' do
   let(:target_url) { 'http://ex.lo/' }
   let(:target)     { WPScan::Target.new(target_url) }
-  let(:fixtures)   { File.join(SPECS, 'output') }
+  let(:fixtures)   { SPECS.join('output') }
 
   # CliNoColour is used to test the CLI output to avoid the painful colours
   # in the expected output.
@@ -14,7 +16,7 @@ describe 'App::Views' do
       let(:parsed_options) { { url: target_url, format: formatter.to_s.underscore.dasherize } }
 
       before do
-        controller.class.parsed_options = parsed_options
+        WPScan::ParsedCli.options = parsed_options
         # Resets the formatter to ensure the correct one is loaded
         controller.class.class_variable_set(:@@formatter, nil)
       end
@@ -23,7 +25,7 @@ describe 'App::Views' do
         view_filename   = defined?(expected_view) ? expected_view : view
         view_filename   = "#{view_filename}.#{formatter.to_s.underscore.downcase}"
         controller_dir  = controller.class.to_s.demodulize.underscore.downcase
-        expected_output = File.read(File.join(fixtures, controller_dir, view_filename))
+        expected_output = File.read(fixtures.join(controller_dir, view_filename))
 
         expect($stdout).to receive(:puts).with(expected_output)
 
